config() {
  NEW="$1"
  OLD="$(dirname $NEW)/$(basename $NEW .new)"
  # If there's no config file by that name, mv it over:
  if [ ! -r $OLD ]; then
    mv $NEW $OLD
  elif [ "$(cat $OLD | md5sum)" = "$(cat $NEW | md5sum)" ]; then # toss the redundant copy
    rm $NEW
  fi
  # Otherwise, we leave the .new copy for the admin to consider...
}

perms() {
  NEW="$1"
  OLD="$(dirname $NEW)/$(basename $NEW .new)"
  if [ -e $OLD ]; then
    cp -a $OLD ${NEW}.incoming
    cat $NEW > ${NEW}.incoming
    mv ${NEW}.incoming $NEW
  fi
  config $NEW
}

perms etc/rc.d/rc.postgresql.new
config etc/logrotate.d/postgresql.new

if ! grep -q "^postgres:" etc/group; then
  if ! grep -q ":209:" etc/group; then
    chroot . groupadd -g 209 postgres &>/dev/null
  else
    chroot . groupadd postgres &>/dev/null
  fi
fi
if ! grep -q "^postgres:" etc/passwd; then
  if ! grep -q ":209:" etc/passwd; then
    chroot . useradd -u 209 -d /var/lib/pgsql -g postgres postgres &>/dev/null
  else
    chroot . useradd -d /var/lib/pgsql -g postgres postgres &>/dev/null
  fi
fi

# Create default program symlinks in /usr/bin
(
  cd usr/bin
  for pg_binary in ../lib64/postgresql/16/bin/*; do
    pg_prog=$(basename $pg_binary)
    if [ -L $pg_prog ]; then
      ln -sf $pg_binary
    elif [ ! -e $pg_prog ]; then
      # make sure we don't overwrite actual binaries
      ln -s $pg_binary
    fi
  done
)

cat << EOF
Before you can run postgresql you'll need to create the
database files in /var/lib/pgsql. The following should do
the trick.
 # su postgres -c "initdb -D /var/lib/pgsql/16/data --locale=en_US.UTF-8 -A md5 -W"

EOF

( cd usr/lib64 ; rm -rf libecpg.so )
( cd usr/lib64 ; ln -sf postgresql/16/lib/libecpg.so libecpg.so )
( cd usr/lib64 ; rm -rf libecpg.so.6 )
( cd usr/lib64 ; ln -sf postgresql/16/lib/libecpg.so.6 libecpg.so.6 )
( cd usr/lib64 ; rm -rf libecpg.so.6.16 )
( cd usr/lib64 ; ln -sf postgresql/16/lib/libecpg.so.6.16 libecpg.so.6.16 )
( cd usr/lib64 ; rm -rf libecpg_compat.so )
( cd usr/lib64 ; ln -sf postgresql/16/lib/libecpg_compat.so libecpg_compat.so )
( cd usr/lib64 ; rm -rf libecpg_compat.so.3 )
( cd usr/lib64 ; ln -sf postgresql/16/lib/libecpg_compat.so.3 libecpg_compat.so.3 )
( cd usr/lib64 ; rm -rf libecpg_compat.so.3.16 )
( cd usr/lib64 ; ln -sf postgresql/16/lib/libecpg_compat.so.3.16 libecpg_compat.so.3.16 )
( cd usr/lib64 ; rm -rf libpgtypes.so )
( cd usr/lib64 ; ln -sf postgresql/16/lib/libpgtypes.so libpgtypes.so )
( cd usr/lib64 ; rm -rf libpgtypes.so.3 )
( cd usr/lib64 ; ln -sf postgresql/16/lib/libpgtypes.so.3 libpgtypes.so.3 )
( cd usr/lib64 ; rm -rf libpgtypes.so.3.16 )
( cd usr/lib64 ; ln -sf postgresql/16/lib/libpgtypes.so.3.16 libpgtypes.so.3.16 )
( cd usr/lib64 ; rm -rf libpq.so )
( cd usr/lib64 ; ln -sf postgresql/16/lib/libpq.so libpq.so )
( cd usr/lib64 ; rm -rf libpq.so.5 )
( cd usr/lib64 ; ln -sf postgresql/16/lib/libpq.so.5 libpq.so.5 )
( cd usr/lib64 ; rm -rf libpq.so.5.16 )
( cd usr/lib64 ; ln -sf postgresql/16/lib/libpq.so.5.16 libpq.so.5.16 )
( cd usr/lib64 ; rm -rf libpqwalreceiver.so )
( cd usr/lib64 ; ln -sf postgresql/16/lib/libpqwalreceiver.so libpqwalreceiver.so )
( cd usr/lib64/pkgconfig ; rm -rf libecpg.pc )
( cd usr/lib64/pkgconfig ; ln -sf ../postgresql/16/lib/pkgconfig/libecpg.pc libecpg.pc )
( cd usr/lib64/pkgconfig ; rm -rf libecpg_compat.pc )
( cd usr/lib64/pkgconfig ; ln -sf ../postgresql/16/lib/pkgconfig/libecpg_compat.pc libecpg_compat.pc )
( cd usr/lib64/pkgconfig ; rm -rf libpgtypes.pc )
( cd usr/lib64/pkgconfig ; ln -sf ../postgresql/16/lib/pkgconfig/libpgtypes.pc libpgtypes.pc )
( cd usr/lib64/pkgconfig ; rm -rf libpq.pc )
( cd usr/lib64/pkgconfig ; ln -sf ../postgresql/16/lib/pkgconfig/libpq.pc libpq.pc )
( cd usr/lib64/postgresql/16/lib ; rm -rf libecpg.so )
( cd usr/lib64/postgresql/16/lib ; ln -sf libecpg.so.6.16 libecpg.so )
( cd usr/lib64/postgresql/16/lib ; rm -rf libecpg.so.6 )
( cd usr/lib64/postgresql/16/lib ; ln -sf libecpg.so.6.16 libecpg.so.6 )
( cd usr/lib64/postgresql/16/lib ; rm -rf libecpg_compat.so )
( cd usr/lib64/postgresql/16/lib ; ln -sf libecpg_compat.so.3.16 libecpg_compat.so )
( cd usr/lib64/postgresql/16/lib ; rm -rf libecpg_compat.so.3 )
( cd usr/lib64/postgresql/16/lib ; ln -sf libecpg_compat.so.3.16 libecpg_compat.so.3 )
( cd usr/lib64/postgresql/16/lib ; rm -rf libpgtypes.so )
( cd usr/lib64/postgresql/16/lib ; ln -sf libpgtypes.so.3.16 libpgtypes.so )
( cd usr/lib64/postgresql/16/lib ; rm -rf libpgtypes.so.3 )
( cd usr/lib64/postgresql/16/lib ; ln -sf libpgtypes.so.3.16 libpgtypes.so.3 )
( cd usr/lib64/postgresql/16/lib ; rm -rf libpq.so )
( cd usr/lib64/postgresql/16/lib ; ln -sf libpq.so.5.16 libpq.so )
( cd usr/lib64/postgresql/16/lib ; rm -rf libpq.so.5 )
( cd usr/lib64/postgresql/16/lib ; ln -sf libpq.so.5.16 libpq.so.5 )
